@@ -1,11 +1,13 @@
 #' Add Rev. Henry Whitehead's Broad Street pump neighborhood.
 #'
 #' A circle (polygon), centered around a desired pump with a radius of 210 yards. The Broad Street pump is the default.
-#' @param radius Numeric. Distance from a pump in yards
-#' @param pump Character. Name of selected pump (road name). See \code{pumps} or \code{pumps.vestry}.
+#' @param radius Numeric. Distance from a pump in yards.
+#' @param pump Character or Numeric. Name (road name) or numerical ID of selected pump. See \code{pumps} or \code{pumps.vestry}.
 #' @param color Character. Color of circle.
 #' @param line.type Character. Circle line type.
 #' @param vestry Logical. TRUE uses the 14 pumps and locations from Vestry report. FALSE uses original 13 pumps.
+#' @param subtitle Logical. Add subtitle with estimated "walking" time in seconds.
+#' @param walking.speed Numeric. km/hr.
 #' @param ... Additional plotting parameters.
 #' @seealso \code{\link{snowMap}},
 #' \code{\link{addIndexCase}},
@@ -22,9 +24,11 @@
 #' snowMap(add.landmarks = FALSE)
 #' addWhitehead()
 
-addWhitehead <- function(pump = "Broad Street", radius = 210, color = "black",
-  line.type = "solid", vestry = FALSE, ...) {
-  r <- radius / 54
+addWhitehead <- function(radius = 210, pump = "Broad Street", color = "black",
+  line.type = "solid", vestry = FALSE, subtitle = FALSE, walking.speed = 5,
+  ...) {
+
+  r <- radius / cholera::unitMeter(1, "yard")
   unit.base <- 100
   unit.radians <- 2 * pi / unit.base
 
@@ -74,4 +78,9 @@ addWhitehead <- function(pump = "Broad Street", radius = 210, color = "black",
     }
   }
   lines(circumference.x, circumference.y, col = color, lty = line.type)
+
+  if (subtitle) {
+    est.time <- distanceTime(unitMeter(r, "native"), speed = walking.speed)
+    title(sub = paste(round(est.time, 1), "secs."))
+  }
 }
