@@ -1,10 +1,11 @@
-#'  Numeric case IDs by pump neighborhood.
+#'  Extract numeric case IDs by pump neighborhood.
 #'
-#' @param obj An object created by neighborhoodVoronoi() or neighborhoodWalking().
-#' @seealso \code{\link{neighborhoodVoronoi}}, \code{\link{neighborhoodWalking}},
-#' @return A list of pump neighborhoods with the numeric ID of cases.
+#' @param obj An object created by neighborhoodEuclidean(), neighborhoodVoronoi() or neighborhoodWalking().
+#' @seealso \code{\link{neighborhoodVoronoi}}, \code{\link{neighborhoodVoronoi}}, \code{\link{neighborhoodEuclidean}},
+#' @return An R list of numeric ID of cases by pump neighborhoods.
 #' @export
 #' @examples
+#' # pumpCase(neighborhoodEuclidean())
 #' # pumpCase(neighborhoodVoronoi())
 #' # pumpCase(neighborhoodWalking())
 
@@ -12,6 +13,20 @@ pumpCase <- function(obj) UseMethod("pumpCase", obj)
 
 pumpCase.default <- function(obj) NULL
 
+#' @export
+pumpCase.euclidean <- function(obj) {
+  if (class(obj) != "euclidean") {
+    stop('Input object\'s class needs to be "euclidean".')
+  }
+
+  pumps <- sort(unique(obj$nearest.pump))
+  out <- lapply(pumps, function(p) {
+    obj$anchors[obj$nearest.pump == p]
+  })
+
+  stats::setNames(out, paste0("p", pumps))
+}
+
 #' @export
 pumpCase.voronoi <- function(obj) {
   if (class(obj) != "voronoi") {
@@ -30,7 +45,7 @@ pumpCase.voronoi <- function(obj) {
       stats::setNames(out, paste0("p", 1:13))
     }
   } else {
-    stats::setNames(out, paste0("p", obj$pump.select))
+    stats::setNames(out, paste0("p", obj$pump.id))
   }
 }
 
