@@ -1,12 +1,13 @@
 #' Compute pump coordinates.
 #'
-#' Returns either the Dodson and Tobler coordinates for the original thirteen pumps, appended with name of nearest road or the fourteen pumps included in the second version of Snow's map in the Vestry report. Note that the location of the fourteenth pump, at Hanover Square, and the "correct" location of the Broad Street pump are approximate.
+#' Returns either the set of x-y coordinate for the pumps themselves or for their orthogonally projected "addresses" on the network of roads.
 #' @param vestry Logical. TRUE uses the 14 pumps from the Vestry report. FALSE uses the 13 in the original map.
 #' @param orthogonal Logical. TRUE returns pump "addresses": the coordinates of the orthogonal projection from a pump's location onto the network of roads. FALSE returns pump location coordinates.
 #' @param multi.core Logical or Numeric. TRUE uses parallel::detectCores(). FALSE uses one, single core. With Numeric, you specify the number logical cores (rounds with as.integer()). On Windows, only "multi.core = FALSE" is available.
+#' @note Note: The location of the fourteenth pump, at Hanover Square, and the "correct" location of the Broad Street pump are approximate.
 #' @seealso\code{\link{pumpLocator}}
 #' @return An R data frame.
-#' @section Notes: This function documents the code that generates \code{\link{pumps}}, \code{\link{pumps.vestry}}, \code{\link{ortho.proj.pump}} and \code{\link{ortho.proj.pump.vestry}}.
+#' @note The Dodson and Tobler coordinates of the original thirteen pumps, appended with name of nearest road, or the fourteen pumps included in the second version of Snow's map included in the Vestry report. This function documents the code that generates \code{\link{pumps}}, \code{\link{pumps.vestry}}, \code{\link{ortho.proj.pump}} and \code{\link{ortho.proj.pump.vestry}}.
 #' @export
 
 pumpData <- function(vestry = FALSE, orthogonal = FALSE, multi.core = FALSE) {
@@ -61,7 +62,7 @@ pumpData <- function(vestry = FALSE, orthogonal = FALSE, multi.core = FALSE) {
 
       within.radius <- lapply(road.segments$id, function(x) {
         dat <- road.segments[road.segments$id == x, ]
-        test1 <- withinRadius(case, dat[, c("x1", "y1")])
+        test1 <- withinRadius(case, dat[, c("x1", "y1")]) # in unstack.R
         test2 <- withinRadius(case, dat[, c("x2", "y2")])
         if (any(test1, test2)) unique(dat$id)
       })
@@ -124,7 +125,3 @@ pumpData <- function(vestry = FALSE, orthogonal = FALSE, multi.core = FALSE) {
   do.call(rbind, orthogonal.projection)
   }
 }
-
-withinRadius <- function(a, b, radius = 2) {
-  (a$x - b$x)^2 + (a$y - b$y)^2 <= radius^2
-}
