@@ -1,7 +1,7 @@
 #' Compute Voronoi pump neighborhoods.
 #'
 #' Group cases into neighborhoods using Voronoi tessellation.
-#' @param pump.select Numeric. Default is NULL: all pumps are used. Otherwise, selection by a vector of numeric IDs: 1 to 13 for \code{pumps}; 1 to 14 for \code{pumps.vestry}. Exclusion (negative selection) is possible (e.g., -6).
+#' @param pump.select Numeric. Vector of numeric pump IDs to define pump neighborhoods (i.e., the "population"). Negative selection possible. NULL selects all pumps.
 #' @param vestry Logical. TRUE uses the 14 pumps from the Vestry Report. FALSE uses the 13 in the original map.
 #' @param statistic NULL or Character. NULL, the default, makes no summary computation. "address" computes the number of addresses in each selected pump neighborhood. "fatality" computes the number of fatalities in pump neighborhoods.
 #' @param polygon.vertices Logical. TRUE returns a list of x-y coordinates of the vertices of Voronoi cells. Useful for sp::point.in.polygon() as used in print.voronoi() method.
@@ -48,6 +48,7 @@ neighborhoodVoronoi <- function(pump.select = NULL, vestry = FALSE,
       if (any(abs(pump.select) %in% 1:14 == FALSE)) {
         stop('With "vestry = TRUE", 1 >= |"pump.select"| <= 14')
       }
+
     } else {
       if (length(unique((1:13)[pump.select])) < 2) {
         stop(msg)
@@ -58,6 +59,12 @@ neighborhoodVoronoi <- function(pump.select = NULL, vestry = FALSE,
     }
   }
 
+  if (vestry) {
+    pump.data <- cholera::pumps.vestry
+  } else {
+    pump.data <- cholera::pumps
+  }
+
   if (is.null(statistic) == FALSE) {
     if (all(statistic %in% c("address", "fatality")) == FALSE) {
       msg <- 'If specified, "statistic" must either be "address" or "fatality".'
@@ -69,43 +76,23 @@ neighborhoodVoronoi <- function(pump.select = NULL, vestry = FALSE,
   y.rng <- range(cholera::roads$y)
 
   if (is.null(pump.select)) {
-    if (vestry) {
-      pump.id <- cholera::pumps.vestry$id
-      voronoi <- deldir::deldir(cholera::pumps.vestry[, c("x", "y")],
-        rw = c(x.rng, y.rng), suppressMsge = TRUE)
-      snow.colors <- cholera::snowColors(vestry = TRUE)
-      select.string <- NULL
-    } else {
-      pump.id <- cholera::pumps$id
-      voronoi <- deldir::deldir(cholera::pumps[, c("x", "y")],
-        rw = c(x.rng, y.rng), suppressMsge = TRUE)
-      snow.colors <- cholera::snowColors()
-      select.string <- NULL
-    }
+    pump.id <- pump.data$id
+    voronoi <- deldir::deldir(pump.data[, c("x", "y")], rw = c(x.rng, y.rng),
+      suppressMsge = TRUE)
+    snow.colors <- cholera::snowColors(vestry = TRUE)
+    select.string <- NULL
   } else {
-    if (vestry) {
-      pump.id <- cholera::pumps.vestry$id[pump.select]
-      voronoi <- deldir::deldir(cholera::pumps.vestry[pump.select, c("x", "y")],
-        rw = c(x.rng, y.rng), suppressMsge = TRUE)
-      snow.colors <- cholera::snowColors(vestry = TRUE)[pump.select]
-      select.string <- paste(sort(pump.select), collapse = ", ")
-    } else {
-      pump.id <- cholera::pumps$id[pump.select]
-      voronoi <- deldir::deldir(cholera::pumps[pump.select, c("x", "y")],
-        rw = c(x.rng, y.rng), suppressMsge = TRUE)
-      snow.colors <- cholera::snowColors()[pump.select]
-      select.string <- paste(sort(pump.select), collapse = ", ")
-    }
+    pump.id <- pump.data$id[pump.select]
+    voronoi <- deldir::deldir(pump.data[pump.select, c("x", "y")],
+      rw = c(x.rng, y.rng), suppressMsge = TRUE)
+    snow.colors <- cholera::snowColors(vestry = TRUE)[pump.select]
+    select.string <- paste(sort(pump.select), collapse = ", ")
   }
 
   cell.data <- voronoi$dirsgs
   voronoi.order <- as.numeric(rownames(voronoi$summary))
 
-  if (vestry) {
-    pump.sel <- cholera::pumps.vestry$id
-  } else {
-    pump.sel <- cholera::pumps$id
-  }
+  pump.sel <- pump.data$id
 
   if (is.null(pump.select)) {
     expected.data <- data.frame(pump = pump.sel[voronoi.order],
@@ -157,6 +144,8 @@ neighborhoodVoronoi <- function(pump.select = NULL, vestry = FALSE,
 #' Plot Voronoi neighborhoods.
 #'
 #' @param x An object of class "voronoi" created by neighborhoodVoronoi().
+#' @param voronoi.cells Logical. Plot Voronoi tessellation cells.
+#' @param euclidean.paths Logical. Plot all Eucldian paths (star graph).
 #' @param ... Additional plotting parameters.
 #' @return A base R graph.
 #' @seealso
@@ -169,7 +158,9 @@ neighborhoodVoronoi <- function(pump.select = NULL, vestry = FALSE,
 #' @examples
 #' plot(neighborhoodVoronoi())
 
-plot.voronoi <- function(x, ...) {
+plot.voronoi <- function(x, voronoi.cells = TRUE,
+  euclidean.paths = FALSE, ...) {
+
   if (class(x) != "voronoi") {
     stop('"x"\'s class needs to be "voronoi".')
   }
@@ -179,44 +170,35 @@ plot.voronoi <- function(x, ...) {
   roads.list <- split(rd[, c("x", "y")], rd$street)
   border.list <- split(map.frame[, c("x", "y")], map.frame$street)
 
+  if (x$vestry) {
+    pump.data <- cholera::pumps.vestry
+  } else {
+    pump.data <- cholera::pumps
+  }
+
   plot(cholera::fatalities.address[, c("x", "y")], xlim = x$x.rng,
     ylim = x$y.rng, pch = NA, asp = 1)
-
   invisible(lapply(roads.list, lines, col = "lightgray"))
   invisible(lapply(border.list, lines))
 
   if (is.null(x$statistic)) {
     if (is.null(x$pump.select)) {
-      if (x$vestry) {
-        points(cholera::pumps.vestry[, c("x", "y")], pch = 2,
-          col = x$snow.colors)
-        text(cholera::pumps.vestry[, c("x", "y")], pos = 1,
-          label = paste0("p", x$pump.id))
-      } else {
-        points(cholera::pumps[, c("x", "y")], pch = 2, col = x$snow.colors)
-        text(cholera::pumps[, c("x", "y")], label = paste0("p", x$pump.id),
-          pos = 1)
-      }
+      points(pump.data[, c("x", "y")], pch = 2, col = x$snow.colors)
+      text(pump.data[, c("x", "y")], pos = 1, label = paste0("p", x$pump.id))
       title(main = "Pump Neighborhoods: Voronoi (address)")
-
     } else {
-      if (x$vestry) {
-        points(cholera::pumps.vestry[x$pump.select, c("x", "y")], pch = 2,
-          col = x$snow.colors)
-        text(cholera::pumps.vestry[x$pump.select, c("x", "y")],
-          label = paste0("p", x$pump.id), pos = 1)
-      } else {
-        points(cholera::pumps[x$pump.select, c("x", "y")], pch = 2,
-          col = x$snow.colors)
-        text(cholera::pumps[x$pump.select, c("x", "y")],
-          label = paste0("p", x$pump.id), pos = 1)
-      }
+      points(pump.data[x$pump.select, c("x", "y")], pch = 2,
+        col = x$snow.colors)
+      text(pump.data[x$pump.select, c("x", "y")],
+        label = paste0("p", x$pump.id), pos = 1)
       title(main = paste0("Pump Neighborhoods: Voronoi (address)", "\n",
         "Pumps ", paste(sort(x$pump.select), collapse = ", ")))
     }
 
-    plot(x$voronoi, add = TRUE, wline = "tess", wpoints = "none",
-      lty = "solid")
+    if (voronoi.cells) {
+      plot(x$voronoi, add = TRUE, wline = "tess", wpoints = "none",
+        lty = "solid")
+    }
 
     voronoi.case.id <- cholera::pumpCase(x)
     voronoi.colors <- vector(length = length(unlist(voronoi.case.id)))
@@ -227,8 +209,23 @@ plot.voronoi <- function(x, ...) {
       voronoi.colors[names(voronoi.colors) %in% id] <- x$snow.colors[i]
     }
 
-    points(cholera::fatalities.address[, c("x", "y")], col = voronoi.colors,
-      pch = 20, cex = 0.75)
+    if (euclidean.paths) {
+      invisible(lapply(names(voronoi.case.id), function(nm) {
+        p.data <- pump.data[paste0("p", pump.data$id) == nm, ]
+        sel <- cholera::fatalities.address$anchor.case %in%
+          voronoi.case.id[[nm]]
+        n.data <- cholera::fatalities.address[sel, ]
+        n.color <- x$snow.colors[nm]
+        lapply(n.data$anchor.case, function(case) {
+          c.data <- n.data[n.data$anchor.case == case, ]
+          segments(c.data$x, c.data$y, p.data$x, p.data$y, col = n.color,
+            lwd = 0.5)
+        })
+      }))
+    } else {
+      points(cholera::fatalities.address[, c("x", "y")], col = voronoi.colors,
+        pch = 20, cex = 0.75)
+    }
 
   } else {
     stat.data <- summary(x)
@@ -239,9 +236,7 @@ plot.voronoi <- function(x, ...) {
         col = polygon.cols[i], border = NA)
     }))
 
-    plot(x$voronoi, add = TRUE, wline = "tess", wpoints = "none",
-      lty = "solid")
-
+    plot(x$voronoi, add = TRUE, wline = "tess", wpoints = "none", lty = "solid")
     invisible(lapply(roads.list, lines, col = "lightgray"))
     invisible(lapply(border.list, lines))
 
@@ -252,30 +247,14 @@ plot.voronoi <- function(x, ...) {
     }
 
     if (is.null(x$pump.select)) {
-      if (x$vestry) {
-        text(cholera::pumps.vestry[, c("x", "y")], label = stat.data$Count)
-        text(cholera::pumps.vestry[, c("x", "y")], pos = 1, cex = 0.8,
-          col = "blue", label = round(stat.data$Pearson, 2))
-      } else {
-        text(cholera::pumps[, c("x", "y")], label = stat.data$Count)
-        text(cholera::pumps[, c("x", "y")], pos = 1, cex = 0.8, col = "blue",
-          label = round(stat.data$Pearson, 2))
-      }
-
+      text(pump.data[, c("x", "y")], label = stat.data$Count)
+      text(pump.data[, c("x", "y")], pos = 1, cex = 0.8,
+        col = "blue", label = round(stat.data$Pearson, 2))
       title(main = caption)
     } else {
-      if (x$vestry) {
-        text(cholera::pumps.vestry[x$pump.select, c("x", "y")],
-          label = stat.data$Count)
-        text(cholera::pumps.vestry[x$pump.select, c("x", "y")], pos = 1,
-          cex = 0.8, col = "blue", label = round(stat.data$Pearson, 2))
-      } else {
-        text(cholera::pumps[x$pump.select, c("x", "y")],
-          label = stat.data$Count)
-        text(cholera::pumps[x$pump.select, c("x", "y")], pos = 1, cex = 0.8,
-          col = "blue", label = round(stat.data$Pearson, 2))
-      }
-
+      text(pump.data[x$pump.select, c("x", "y")], label = stat.data$Count)
+      text(pump.data[x$pump.select, c("x", "y")], pos = 1, cex = 0.8,
+        col = "blue", label = round(stat.data$Pearson, 2))
       title(main = paste0(caption, "\n", "Pumps ", x$select.string))
     }
   }
